export default rehypeMathJaxBrowser
export type Options = import('./lib/create-plugin').Options
declare const rehypeMathJaxBrowser: (
  this: import('unified').Processor<void, import('hast').Root, void, void>,
  options?: void | import('./lib/create-plugin.js').Options | undefined
) =>
  | void
  | import('unified').Transformer<import('hast').Root, import('hast').Root>
