/**
 * @param {Options} options
 * @param {OutputJax} output
 * @returns {Renderer}
 */
export function createRenderer(
  options: Options,
  output: import('mathjax-full/js/core/OutputJax').OutputJax<
    HTMLElement,
    Text,
    Document
  >
): Renderer
export type Element = import('hast').Element
export type OutputJax = import('mathjax-full/js/core/OutputJax').OutputJax<
  HTMLElement,
  Text,
  Document
>
export type MathDocument =
  import('mathjax-full/js/core/MathDocument.js').MathDocument<
    HTMLElement,
    Text,
    Document
  >
export type TeX_ = import('mathjax-full/js/input/tex.js').TeX<
  HTMLElement,
  Text,
  Document
>
export type Options = import('./create-plugin.js').Options
export type Renderer = import('./create-plugin.js').Renderer
